@@ -206,7 +206,7 @@ def print_clusters(config):
 
 
 def print_completion(shell):
-	if shell == 'bash':
+	if shell in ['bash', 'zsh']:
 		with open(resource_path(f'autocomplete.{shell}')) as f:
 			completion = f.read()
 		print(completion)
